<?php
# ------------------------------------------------------------------------
# Eigene Funktionen zur Steuerung von Raspi Sensoren und GPIO Elementen
# ------------------------------------------------------------------------
function getSensoren()
{
// Die gefundenen Verzeichnisse inklusive w1_slave Datei und der Sensortyp werden als Array durch die Funktion zurückgegeben.
$ausgabe = array();
$AnzahlSensoren = 0;

/* bekannte Sensortypen
10-: DS18S20 oder DS1820 Temperatursensor
22-: DS1822 Temperatursensor
28-: DS18B20 Temperatursensor
*/
$Sensortypen = array();
$Sensortypen[0] = 10;
$Sensortypen[1] = 22;
$Sensortypen[2] = 28;

// Pfad zum 1-Wire-Geräteverzeichnis
$SensorPfad = '/sys/bus/w1/devices/';

// Die Verzeichnisse im 1-Wire-Geräteverzeichnis auflisten
$directories = scandir($SensorPfad);

// Durch jedes Verzeichnis iterieren
foreach ($directories as $directory) {
    //Typ aus Verzeichnisnamen ermitteln
    $SensorTyp = substr($directory,0,2);

    // Wenn das Verzeichnis eine Sensor-ID enthält (beginnt mit 'xx-')
    
    if (in_array($SensorTyp, $Sensortypen)) {
        // Den Pfad zur w1_slave-Datei des Sensors erstellen
        $SensorFile = $SensorPfad . $directory . '/w1_slave';
        $ausgabe[$AnzahlSensoren] = ['SensorFile' => $SensorFile, 'SensorTyp' => $SensorTyp];
        $AnzahlSensoren=$AnzahlSensoren+1;
    }
}

return $ausgabe;

}

function getTemperatur($in_SensorFile, $in_SensorTyp)
{
// Pfad zum Sensor, ersetzen Sie '28-XXXX' durch die ID Ihres Sensors
// Beispielpfad '/sys/bus/w1/devices/28-XXXX/w1_slave';


/* 
Inhalt von w1_slave
aktuell installiert an Borgauge : /sys/bus/w1/devices/28-80000007accb/w1_slave

5e 00 ff ff 7f ff ff ff 6f : crc=6f YES
5e 00 ff ff 7f ff ff ff 6f t=5875

Inhalt von w1_slave im Fehlerfall
00 00 00 00 00 00 00 00 00 : crc=00 YES
00 00 00 00 00 00 00 00 00 t=0
*/

// Prüfen ob die Datei für den Sensor überhaupt existiert, Wenn nicht ->x Fehler
if (file_exists($in_SensorFile) == false)     
    { $out_Sensorwert =  "# -273K - Fehler - Sensor nicht gefunden!"; }
else
{

// Die Datei öffnen
$file = fopen($in_SensorFile, 'r');

// Die Daten aus der Datei lesen
$data = fread($file, filesize($in_SensorFile));

// Die Datei schließen
fclose($file);

// fehlerhaften Sensor prüfen
$SucheNach = "00 00 00 00 00 00 00 00 00 : crc=00 YES";
$Position = strpos($data, $SucheNach);
$SensorOkay = false;

// Echo "Position:".$Position."<br>";
// Echo $data."<br>";

if ($Position === false) { $SensorOkay = true; /*Der String wurde nicht im Text gefunden*/ } 
if ($Position === 0) { $SensorOkay = false; /*Der String wurde im Text gefunden*/ } 

if ($SensorOkay === true) {
    // Die Temperaturdaten aus der Datei extrahieren
    preg_match("/t=(.+)/", $data, $matches);
    $out_Sensorwert = $matches[1] / 1000;
}
else {
    $out_Sensorwert =  "# -273K - Fehler - Sensorwertermittlung!";
}

}

return $out_Sensorwert;

}


function getTemperaturADT7410()
{
    $ADT7410Temperatur = trim(@shell_exec("python /var/www/html/StarCatcher/04extern/readADT7410.py"));
    $out_Sensorwert = $ADT7410Temperatur;

    return $out_Sensorwert;
}


function getTemperaturDHT22()
{
    include "./03config/sensoren.config";
    $shellcmd = "python /var/www/html/StarCatcher/04extern/readDHT22_temp.py ".$DHT22Typ." ".$DHT22Pin;
    $DHT22Wert = trim(@shell_exec($shellcmd));
    $out_Sensorwert = $DHT22Wert;

    return $out_Sensorwert;
}

function getFeuchtigkeitDHT22()
{
    include "./03config/sensoren.config";
    $shellcmd = "python /var/www/html/StarCatcher/04extern/readDHT22_humi.py ".$DHT22Typ." ".$DHT22Pin;
    $DHT22Wert = trim(@shell_exec($shellcmd));
    $out_Sensorwert = $DHT22Wert;

    return $out_Sensorwert;
}